@@ -17,7 +17,7 @@ exec(''.join([x for x in path('setup.py').lines() if 'setuptools' not in x]))
 
 
 @task
-@needs(['resolve', 'clean', 'test'])
+@needs(['resolve', 'clean', 'test', 'docs'])
 def all():
     pass
 
@@ -28,10 +28,24 @@ def resolve():
     pip.main(['install', '-r', 'requirements.txt', '--use-mirrors'])
 
 
+@task
+@needs(['build_sphinx'])
+def docs():
+    htmlpath = path('build') / 'sphinx' / 'html'
+    docspath = path('build')
+    shutil.move(htmlpath, docspath)
+    os.rename(docspath / 'html', docspath / 'docs')
+
+
+@task
+@needs(['docs', 'upload_docs'])
+def upload_docs():
+    pass
+
 @task
 def clean():
-    paths = (glob('dist/') + glob('build/') + glob('pageit.egg-info/') +
-             glob('MANIFEST') + glob('.coverage') + glob('paver-minilib.zip'))
+    paths = (glob('dist/') + glob('build/') + glob('tmp/') +
+             glob('pageit.egg-info/') + glob('MANIFEST') + glob('.coverage'))
 
     for pattern in ['*.pyc', '*.*~']:
         paths += glob(pattern) + glob('*/' + pattern)
@@ -58,11 +72,10 @@ def test():
 
 @task
 def _nose():
-    import nose
-    path = os.path.join(os.path.abspath('.'), 'pageit')
-    args = ['', '--with-doctest', '--with-coverage', '--cover-package=pageit']
-    args += glob(os.path.join(path, '*.py'))
-    nose.run(argv=args)
+    args = ['nosetests', '--all-modules', '--traverse-namespace',
+            '--with-doctest',
+            '--with-coverage', '--cover-package=pageit']
+    sh(' '.join(args))
 
 
 @task
